/*
 *  Copyright (C) 1998  Luca Deri <deri@unipi.it>
 *                      Stefano Suin <stefano@unipi.it>
 *                      
 * 			Centro SERRA, University of Pisa
 * 			http://www-serra.unipi.it/
 *  					
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "ntop.h"

/*
 ************************************************
 * 
 * Most of the information contained in this file 
 * has been taken from K-Arp-Ski 
 * by Brian Costello <btx@calyx.net>.
 *
 * Thanks Brian!
 *
 * **********************************************
 */

typedef struct {
  unsigned long vendorId;
  char* vendorName;
} VendorInfo;

static VendorInfo vendorInfo[] = {
  { 0x000001, "SuperLAN-2U" },
  { 0x000002, "BBN" },
  { 0x000009, "Powerpipes" },
  { 0x00000C, "Cisco" },
  { 0x00000E, "Fujitsu" },
  { 0x00000F, "NeXT" },
  { 0x000010, "Hughes LAN Sys" },
  { 0x000011, "Tektronix" },
  { 0x000015, "Datapoint Corp" },
  { 0x000018, "Webster" },
  { 0x00001A, "AMD" },
  { 0x00001B, "Eagle Tech" },
  { 0x00001C, "JDR Microdevices" },
  { 0x00001D, "Cabletron" },
  { 0x00001F, "Cryptall Comm Corp" },
  { 0x000020, "Data Intdustrier AB" },
  { 0x000021, "SC&C" },
  { 0x000022, "Visual Tech" },
  { 0x000023, "ABB Automation" },
  { 0x000024, "Olicom" },
  { 0x000029, "IMC" },
  { 0x00002A, "TRW" },
  { 0x00002C, "NRC" },
  { 0x000032, "GPT" },
  { 0x000037, "Oxford Metrics" },
  { 0x00003B, "Hyundai/Axil" },
  { 0x00003C, "Auspex" },
  { 0x00003D, "AT&T" },
  { 0x00003F, "Syntrex Inc" },
  { 0x000044, "Castelle" },
  { 0x000046, "ISC-Bunker Ramo" },
  { 0x000048, "Epson" },
  { 0x000049, "Apricot" },
  { 0x00004B, "APT-ICL" },
  { 0x00004C, "NEC Corp" },
  { 0x00004F, "Logicraft" },
  { 0x000051, "Hob Electronic Gmbh" },
  { 0x000052, "Optical Data Sys" },
  { 0x000055, "AT&T" },
  { 0x000058, "Racore Computer Products Inc" },
  { 0x00005A, "SK" },
  { 0x00005A, "Xerox 806" },
  { 0x00005B, "Eltec" },
  { 0x00005D, "RCE" },
  { 0x00005E, "U.S. Dept of Defense (IANA)" },
  { 0x00005F, "Sumitomo" },
  { 0x000061, "Gateway Comm" },
  { 0x000062, "Honeywell" },
  { 0x000063, "Hewlett-Packard" },
  { 0x000064, "Yokogawa" },
  { 0x000065, "Network General" },
  { 0x000066, "Talaris" },
  { 0x000069, "Concord Comm" },
  { 0x00006B, "MIPS" },
  { 0x00006D, "Case" },
  { 0x00006E, "Artisoft" },
  { 0x00006F, "Madge Networks" },
  { 0x000068, "Rosemount Controls" },
  { 0x00006F, "Madge Networks" },
  { 0x000073, "DuPont" },
  { 0x000075, "Bell Northern" },
  { 0x000077, "Interphase" },
  { 0x000078, "Labtam Australia" },
  { 0x000079, "Networth Incorporated" },
  { 0x00007A, "Ardent" },
  { 0x00007B, "Research Machines" },
  { 0x00007D, "Cray Research" },
  { 0x00007E, "NetFRAME" },
  { 0x00007F, "Linotype-Hell AG" },
  { 0x000080, "Cray Comm" },
  { 0x000081, "Synoptics" },
  { 0x000083, "Tadpole Tech" },
  { 0x000084, "ADI Sys Inc" },
  { 0x000086, "Gateway Comm" },
  { 0x000087, "Hitachi" },
  { 0x000089, "Cayman Sys" },
  { 0x00008A, "Datahouse Information Sys" },
  { 0x00008E, "Solbourne" },
  { 0x000092, "Unisys, Cogent" },
  { 0x000093, "Proteon" },
  { 0x000094, "Asante" },
  { 0x000095, "Sony/Tektronix" },
  { 0x000097, "Epoch" },
  { 0x000098, "Cross Com" },
  { 0x000099, "Memorex" },
  { 0x00009F, "Ameristar Tech" },
  { 0x0000A0, "Sanyo Electronics" },
  { 0x0000A2, "Wellfleet" },
  { 0x0000A3, "Network Appl Tech" },
  { 0x0000A4, "Acorn" },
  { 0x0000A5, "Compatible Sys Cor" },
  { 0x0000A6, "Network General" },
  { 0x0000A7, "Network Comp. Dev" },
  { 0x0000A8, "Stratus Computer" },
  { 0x0000A9, "Network Sys" },
  { 0x0000AA, "Xerox" },
  { 0x0000AC, "Conware Netzpartner" },
  { 0x0000AE, "Dassault" },
  { 0x0000AF, "Nuclear Data" },
  { 0x0000B0, "RAD Network Devices" },
  { 0x0000B1, "Alpha MicroSys Inc" },
  { 0x0000B3, "CIMLinc" },
  { 0x0000B4, "Edimax" },
  { 0x0000B5, "Datability Terminal Servers" },
  { 0x0000B6, "Micro-matic Research" },
  { 0x0000B7, "Dove" },
  { 0x0000BB, "TRI-DATA Sys Inc" },
  { 0x0000BC, "Allen-Bradley" },
  { 0x0000C0, "Western Digital" },
  { 0x0000C1, "Olicom A/S" },
  { 0x0000C5, "Farallon Computing Inc" },
  { 0x0000C6, "Hewlett-Packard" },
  { 0x0000C8, "Altos" },
  { 0x0000C9, "Emulex" },
  { 0x0000CA, "BayNetworks" },
  { 0x0000CC, "Densan Co" },
  { 0x0000CD, "Industrial Research" },
  { 0x0000D0, "Develcon Electronics" },
  { 0x0000D1, "Adaptec" },
  { 0x0000D2, "SBE Inc" },
  { 0x0000D3, "Wang Labs" },
  { 0x0000D4, "PureData" },
  { 0x0000D7, "Dartmouth College" },
  { 0x0000D8, "3Com" },
  { 0x0000DD, "Gould" },
  { 0x0000DE, "Unigraph" },
  { 0x0000E1, "Hitachi" },
  { 0x0000E2, "Acer Counterpoint" },
  { 0x0000E3, "Integrated Micro Products" },
  { 0x0000E4, "MIPS" },
  { 0x0000E6, "Aptor Produits De Comm Indust" },
  { 0x0000E8, "Accton Tech Corp" },
  { 0x0000E9, "ISICAD" },
  { 0x0000ED, "April" },
  { 0x0000EE, "Network Designers" },
  { 0x0000EF, "Alantec" },
  { 0x0000F0, "Samsung" },
  { 0x0000F2, "Spider Comm" },
  { 0x0000F3, "Gandalf Data" },
  { 0x0000F4, "Allied Telesis" },
  { 0x0000F6, "A.M.C" },
  { 0x0000F8, "DEC" },
  { 0x0000FB, "Rechner zur Kommunikation" },
  { 0x0000FD, "High Level Hardware" },
  { 0x0000FF, "Camtec Electronics" },
  { 0x000102, "BBN" },
  { 0x000143, "IEEE 802" },
  { 0x000163, "NDC" },
  { 0x000168, "W&G" },
  { 0x0001C8, "Thomas Conrad Corp" },
  { 0x0001FA, "Compaq" },
  { 0x000204, "Novell NE3200" },
  { 0x000205, "Hamilton" },
  { 0x000216, "ESI" },
  { 0x000288, "Global Village" },
  { 0x0003C6, "Morning Star Tech" },
  { 0x000400, "Lexmark" },
  { 0x0004AC, "IBM" },
  { 0x000502, "Apple" },
  { 0x00059A, "PowerComputing" },
  { 0x0005A8, "PowerComputing" },
  { 0x00060D, "Hewlett-Packard" },
  { 0x00067C, "Cisco" },
  { 0x0006C1, "Cisco" },
  { 0x000701, "Racal-Datacom" },
  { 0x00070D, "Cisco" },
  { 0x000852, "Tech. Elite Concepts" },
  { 0x000855, "Fermilab" },
  { 0x0008C7, "Compaq" },
  { 0x001011, "Cisco" },
  { 0x00101F, "Cisco" },
  { 0x00102F, "Cisco" },
  { 0x00104B, "3Com" },
  { 0x001079, "Cisco" },
  { 0x001700, "Kabel" },
  { 0x002000, "Lexmark" },
  { 0x002008, "Cable & Computer Tech" },
  { 0x00200C, "Adastra Sys Corp" },
  { 0x002011, "Canopus Co" },
  { 0x002017, "Orbotech" },
  { 0x002018, "Realtek" },
  { 0x00201A, "Nbase" },
  { 0x002025, "Control Tech Inc" },
  { 0x002028, "Bloomberg" },
  { 0x00202B, "ATML" },
  { 0x002035, "IBM" },
  { 0x002036, "BMC Software" },
  { 0x002042, "Datametrics Corp" },
  { 0x002045, "SolCom Sys" },
  { 0x002048, "Fore Sys Inc" },
  { 0x00204B, "Autocomputer Co" },
  { 0x00204C, "Mitron Computer Pte" },
  { 0x002056, "Neoproducts" },
  { 0x002061, "Dynatech Comm Inc" },
  { 0x002063, "Wipro Infotech" },
  { 0x002066, "General Magic Inc" },
  { 0x002067, "Node Runner Inc" },
  { 0x00206B, "Minolta" },
  { 0x002078, "Runtop Inc" },
  { 0x002085, "3Com" },
  { 0x00208A, "Sonix Comm" },
  { 0x00208B, "Focus Enhancements" },
  { 0x00208C, "Galaxy Networks Inc" },
  { 0x002094, "Cubix Corp" },
  { 0x0020A5, "Newer Tech" },
  { 0x0020A6, "Proxim Inc" },
  { 0x0020AF, "3Com" },
  { 0x0020B6, "Agile Networks Inc" },
  { 0x0020B9, "Metricom" },
  { 0x0020C5, "Eagle NE2000" },
  { 0x0020C6, "NECTEC" },
  { 0x0020D2, "RAD Data Comm" },
  { 0x0020D3, "OST" },
  { 0x0020D8, "NetWave" },
  { 0x0020DA, "Xylan" },
  { 0x0020DC, "Densitron Taiwan" },
  { 0x0020E0, "InfoExpress" },
  { 0x0020E5, "Apex Data" },
  { 0x0020EE, "Gtech Corp" },
  { 0x0020F6, "Net Tek & Karlnet Inc" },
  { 0x0020F8, "Carrera Computers Inc" },
  { 0x004001, "ZyXEL" },
  { 0x004005, "TRENDware Int" },
  { 0x004009, "Tachibana Tectron Co" },
  { 0x00400B, "Crescendo" },
  { 0x00400C, "General Micro Sys" },
  { 0x00400D, "LANNET" },
  { 0x004010, "Sonic" },
  { 0x004011, "FAEC" },
  { 0x004013, "NTT" },
  { 0x004014, "Comsoft Gmbh" },
  { 0x004015, "Ascom" },
  { 0x004017, "XCd" },
  { 0x00401C, "AST" },
  { 0x00401F, "Colorgraph" },
  { 0x004020, "Pilkington Communication" },
  { 0x004023, "Logic Corp" },
  { 0x004025, "Molecular Dynamics" },
  { 0x004026, "Melco Inc" },
  { 0x004027, "SMC" },
  { 0x004028, "Netcomm" },
  { 0x00402A, "Canoga-Perkins" },
  { 0x00402B, "TriGem" },
  { 0x00402F, "Xlnt Designs Inc (XDI)" },
  { 0x004030, "GK Computer" },
  { 0x004032, "Digital Comm" },
  { 0x004033, "Addtron Tech" },
  { 0x004036, "TribeStar" },
  { 0x004039, "Optec" },
  { 0x00403C, "Forks" },
  { 0x004041, "Fujikura" },
  { 0x004043, "Nokia Data Comm" },
  { 0x004048, "SMD Informatica S.A" },
  { 0x00404C, "Hypertec Pty" },
  { 0x00404D, "Telecomm Techniques" },
  { 0x00404F, "Space & Naval Warfare Sys" },
  { 0x004050, "Ironics" },
  { 0x004052, "Star Tech" },
  { 0x004054, "Thinking Machines Corp" },
  { 0x004057, "Lockheed-Sanders" },
  { 0x004059, "Yoshida Kogyo K.K" },
  { 0x00405B, "Funasset" },
  { 0x00405D, "Star-Tek Inc" },
  { 0x004066, "Hitachi Cable, " },
  { 0x004067, "Omnibyte Corp" },
  { 0x004068, "Extended Sys" },
  { 0x004069, "Lemcom Sys Inc" },
  { 0x00406A, "Kentek Inf. Sys" },
  { 0x00406E, "Corollary" },
  { 0x00406F, "Sync Research Inc" },
  { 0x004072, "Applied Innovation" },
  { 0x004074, "Cable and Wireless" },
  { 0x004076, "AMP Incorporated" },
  { 0x004078, "Wearnes Automation Pte" },
  { 0x00407F, "Agema Infrared Sys AB" },
  { 0x004082, "Laboratory Equipment Corp" },
  { 0x004085, "SAAB Instruments AB" },
  { 0x004086, "Michels & Kleberhoff Computer" },
  { 0x004087, "Ubitrex Corp" },
  { 0x004088, "Mobuis" },
  { 0x00408A, "TPS Teleprocessing Sys. Gmbh" },
  { 0x00408C, "Axis Comm AB" },
  { 0x00408E, "CXR/Digilog" },
  { 0x00408F, "WM-Data Minfo AB" },
  { 0x004090, "Ansel Comm" },
  { 0x004091, "Procomp Industria Eletronica" },
  { 0x004092, "ASP Computer Products" },
  { 0x004094, "Shographics Inc" },
  { 0x004095, "Eagle Technologies" },
  { 0x004096, "TeleSys SLW Inc" },
  { 0x00409A, "Network Express Inc" },
  { 0x00409C, "Transware" },
  { 0x00409D, "DigiBoard" },
  { 0x00409E, "Concurrent Technologies" },
  { 0x00409F, "Lancast/Casat Tech Inc" },
  { 0x0040A4, "Rose Electronics" },
  { 0x0040A6, "Cray Research Inc" },
  { 0x0040AA, "Valmet Automation Inc" },
  { 0x0040AD, "SMA Regelsysteme Gmbh" },
  { 0x0040AE, "Delta Controls" },
  { 0x0040AF, "Digital Products" },
  { 0x0040B4, "3Com" },
  { 0x0040B5, "Video Tech Computers" },
  { 0x0040B6, "Computerm Corp" },
  { 0x0040B9, "MACQ Electronique SA" },
  { 0x0040BD, "Starlight Networks Inc" },
  { 0x0040C1, "Bizerba-Werke Wilheim Kraut" },
  { 0x0040C2, "Applied Computing Devices" },
  { 0x0040C3, "Fischer and Porter Co" },
  { 0x0040C5, "Micom Comm Corp" },
  { 0x0040C6, "Fibernet Research" },
  { 0x0040C7, "Danpex Corp" },
  { 0x0040C8, "Milan Tech Corp" },
  { 0x0040CC, "Silcom Manufacturing Tech Inc" },
  { 0x0040CF, "Strawberry Tree Inc" },
  { 0x0040D2, "Pagine Corp" },
  { 0x0040D4, "Gage Talker Corp" },
  { 0x0040D7, "Studio Gen Inc" },
  { 0x0040D8, "Ocean Office Automation" },
  { 0x0040DC, "Tritec Electronic Gmbh" },
  { 0x0040DF, "Digalog Sys" },
  { 0x0040E1, "Marner Int Inc" },
  { 0x0040E2, "Mesa Ridge Technologies Inc" },
  { 0x0040E3, "Quin Sys" },
  { 0x0040E5, "Sybus Corp" },
  { 0x0040E7, "Arnos Instruments & Computer" },
  { 0x0040E9, "Accord Sys" },
  { 0x0040EA, "PlainTree Sys Inc" },
  { 0x0040ED, "Network Controls Int Inc" },
  { 0x0040F0, "Micro Sys Inc" },
  { 0x0040F1, "Chuo Electronics Co., " },
  { 0x0040F4, "Cameo Comm" },
  { 0x0040F5, "OEM Engines" },
  { 0x0040F6, "Katron Computers Inc" },
  { 0x0040F9, "Combinet" },
  { 0x0040FA, "Microboards Inc" },
  { 0x0040FB, "Cascade Comm Corp" },
  { 0x0040FD, "LXE" },
  { 0x0040FF, "Telebit Corp" },
  { 0x004F49, "Realtek" },
  { 0x004F4B, "Pine Tech" },
  { 0x00504D, "Repotec Group" },
  { 0x00504E, "UMC" },
  { 0x006008, "3Com" },
  { 0x006009, "Cisco" },
  { 0x006025, "Active Imaging Inc" },
  { 0x00602F, "Cisco" },
  { 0x00603E, "Cisco" },
  { 0x006047, "Cisco" },
  { 0x006052, "Realtek" },
  { 0x00605C, "Cisco" },
  { 0x006067, "Acer Lan" },
  { 0x006070, "Cisco" },
  { 0x006083, "Cisco" },
  { 0x00608C, "3Com" },
  { 0x006094, "AMD PCNET PCI" },
  { 0x006097, "3Com" },
  { 0x0060B0, "Hewlett-Packard" },
  { 0x008000, "Multitech Sys Inc" },
  { 0x008001, "Periphonics Corp" },
  { 0x008004, "Antlow Computers, " },
  { 0x008005, "Cactus Computer Inc" },
  { 0x008006, "Compuadd Corp" },
  { 0x008007, "Dlog NC-Systeme" },
  { 0x00800D, "Vosswinkel FU" },
  { 0x00800F, "SMC" },
  { 0x008010, "Commodore" },
  { 0x008012, "IMS Corp" },
  { 0x008013, "Thomas Conrad Corp" },
  { 0x008015, "Seiko Sys Inc" },
  { 0x008016, "Wandel & Goltermann" },
  { 0x008017, "PFU" },
  { 0x008019, "Dayna Comm" },
  { 0x00801A, "Bell Atlantic" },
  { 0x00801B, "Kodiak Tech" },
  { 0x008021, "Newbridge" },
  { 0x008023, "Integrated Business Networks" },
  { 0x008024, "Kalpana" },
  { 0x008026, "Network Products Corp" },
  { 0x008029, "Microdyne Corp" },
  { 0x00802A, "Test Sys & Simulations Inc" },
  { 0x00802C, "The Sage Group PLC" },
  { 0x00802D, "Xylogics" },
  { 0x00802E, "Plexcom" },
  { 0x008033, "Formation" },
  { 0x008034, "SMT-Goupil" },
  { 0x008035, "Tech Works" },
  { 0x008037, "Ericsson" },
  { 0x008038, "Data Research & Applications" },
  { 0x00803B, "APT Comm" },
  { 0x00803D, "Surigiken Co" },
  { 0x00803E, "Synernetics" },
  { 0x00803F, "Hyundai Electronics" },
  { 0x008042, "Force Computers" },
  { 0x008043, "Networld Inc" },
  { 0x008045, "Matsushita Electric Ind Co" },
  { 0x008046, "University of Toronto" },
  { 0x008048, "Compex" },
  { 0x008049, "Nissin Electric Co" },
  { 0x00804C, "Contec Co., " },
  { 0x00804D, "Cyclone MicroSys" },
  { 0x008051, "ADC Fibermux" },
  { 0x008052, "Network Professor" },
  { 0x008057, "Adsoft" },
  { 0x00805A, "Tulip" },
  { 0x00805B, "Condor Sys" },
  { 0x00805C, "Agilis" },
  { 0x00805F, "Compaq Computer Corp" },
  { 0x008060, "Network Interface Corp" },
  { 0x008062, "Interface Co" },
  { 0x008063, "Richard Hirschmann Gmbh & Co" },
  { 0x008064, "Wyse" },
  { 0x008067, "Square D Company" },
  { 0x008069, "Computone Sys" },
  { 0x00806A, "Empac Research Inc" },
  { 0x00806B, "Schmid Telecommunication" },
  { 0x00806C, "Cegelec Projects" },
  { 0x00806D, "Century Sys Corp" },
  { 0x00806E, "Nippon Steel Corp" },
  { 0x00806F, "Onelan" },
  { 0x008071, "SAI Tech" },
  { 0x008072, "Microplex Sys" },
  { 0x008074, "Fisher Controls" },
  { 0x008079, "Microbus Designs" },
  { 0x00807B, "Artel Comm Corp" },
  { 0x00807C, "FiberCom" },
  { 0x00807D, "Equinox Sys Inc" },
  { 0x008082, "PEP Modular Computers Gmbh" },
  { 0x008086, "Computer Generation Inc" },
  { 0x008087, "Okidata" },
  { 0x00808A, "Summit" },
  { 0x00808B, "Dacoll" },
  { 0x00808C, "Frontier Software Development" },
  { 0x00808D, "Westcove Tech BV" },
  { 0x00808E, "Radstone Tech" },
  { 0x008090, "Microtek Int Inc" },
  { 0x008092, "Japan Computer Industry" },
  { 0x008093, "Xyron Corp" },
  { 0x008094, "Sattcontrol AB" },
  { 0x008096, "HDS" },
  { 0x008098, "TDK Corp" },
  { 0x00809A, "Novus Networks" },
  { 0x00809B, "Justsystem Corp" },
  { 0x00809D, "Datacraft Manufactur'g Pty" },
  { 0x00809F, "Alcatel Business Sys" },
  { 0x0080A1, "Microtest" },
  { 0x0080A3, "Lantronix" },
  { 0x0080A6, "Republic Tech Inc" },
  { 0x0080A7, "Measurex Corp" },
  { 0x0080AD, "CNet Tech" },
  { 0x0080AE, "Hughes Network Sys" },
  { 0x0080AF, "Allumer Co., " },
  { 0x0080B1, "Softcom A/S" },
  { 0x0080B2, "NET" },
  { 0x0080B6, "Themis Corp" },
  { 0x0080BA, "Specialix Pte" },
  { 0x0080C0, "Penril Datability Networks" },
  { 0x0080C2, "IEEE" },
  { 0x0080C6, "Soho" },
  { 0x0080C7, "Xircom" },
  { 0x0080C8, "D-Link" },
  { 0x0080C9, "Alberta Microelectronic Centre" },
  { 0x0080CE, "Broadcast Television Sys" },
  { 0x0080D0, "Computer Products Int" },
  { 0x0080D3, "Shiva" },
  { 0x0080D4, "Chase" },
  { 0x0080D6, "Apple" },
  { 0x0080D7, "Fantum Electronics" },
  { 0x0080D8, "Network Peripherals" },
  { 0x0080DA, "Bruel & Kjaer" },
  { 0x0080E0, "XTP Sys Inc" },
  { 0x0080E3, "Coral" },
  { 0x0080E7, "Lynwood Scientific Dev" },
  { 0x0080EA, "The Fiber Company" },
  { 0x0080F0, "Kyushu Matsushita Electric Co" },
  { 0x0080F1, "Opus" },
  { 0x0080F3, "Sun Electronics Corp" },
  { 0x0080F4, "Telemechanique Electrique" },
  { 0x0080F5, "Quantel" },
  { 0x0080F7, "Zenith Comm Products" },
  { 0x0080FB, "BVM" },
  { 0x0080FE, "Azure Technologies Inc" },
  { 0x00A000, "Bay Networks" },
  { 0x00A092, "Intermate Int" },
  { 0x00A0D1, "National Semicond" },
  { 0x00A0D2, "Allied Telesyn" },
  { 0x00A024, "3Com" },
  { 0x00A040, "Apple" },
  { 0x00A0C9, "Intel" },
  { 0x00A0CC, "MacSense" },
  { 0x00AA00, "Intel" },
  { 0x00B0D0, "Computer Products Int" },
  { 0x00C000, "Lanoptics" },
  { 0x00C001, "Diatek Patient Managment" },
  { 0x00C002, "Sercomm Corp" },
  { 0x00C003, "Globalnet Comm" },
  { 0x00C004, "Japan Business Comp" },
  { 0x00C005, "Livingston" },
  { 0x00C006, "Nippon Avionics Co" },
  { 0x00C007, "Pinnacle Data Sys Inc" },
  { 0x00C008, "Seco SRL" },
  { 0x00C009, "KT Tech (s) Pte Inc" },
  { 0x00C00A, "Micro Craft" },
  { 0x00C00B, "Norcontrol A.S" },
  { 0x00C00C, "ARK PC Tech" },
  { 0x00C00D, "Advanced Logic Research Inc" },
  { 0x00C00E, "Psitech Inc" },
  { 0x00C00F, "QNX" },
  { 0x00C011, "Interactive Computing Devices" },
  { 0x00C012, "Netspan Corp" },
  { 0x00C013, "Netrix" },
  { 0x00C014, "Telematics Calabasas" },
  { 0x00C015, "New Media Corp" },
  { 0x00C016, "Electronic Theatre Controls" },
  { 0x00C017, "Fluke" },
  { 0x00C018, "Lanart Corp" },
  { 0x00C01A, "Corometrics Medical Sys" },
  { 0x00C01B, "Socket Comm" },
  { 0x00C01C, "Interlink Comm" },
  { 0x00C01D, "Grand Junction Networks" },
  { 0x00C01F, "S.E.R.C.E.L" },
  { 0x00C020, "Arco Electronic, Control" },
  { 0x00C021, "Netexpress" },
  { 0x00C023, "Tutankhamon Electronics" },
  { 0x00C024, "Eden Sistemas De Computacao SA" },
  { 0x00C025, "Dataproducts Corp" },
  { 0x00C027, "Cipher Sys" },
  { 0x00C028, "Jasco Corp" },
  { 0x00C029, "Kabel Rheydt AG" },
  { 0x00C02A, "Ohkura Electric Co" },
  { 0x00C02B, "Gerloff Gesellschaft Fur" },
  { 0x00C02C, "Centrum Comm" },
  { 0x00C02D, "Fuji Photo Film Co., " },
  { 0x00C02E, "Netwiz" },
  { 0x00C02F, "Okuma Corp" },
  { 0x00C030, "Integrated Engineering B. V" },
  { 0x00C031, "Design Research Sys" },
  { 0x00C032, "I-Cubed" },
  { 0x00C033, "Telebit Corp" },
  { 0x00C034, "Dale Computer Corp" },
  { 0x00C035, "Quintar Company" },
  { 0x00C036, "Raytech Electronic Corp" },
  { 0x00C039, "Silicon Sys" },
  { 0x00C03B, "Multiaccess Computing Corp" },
  { 0x00C03C, "Tower Tech S.R.L" },
  { 0x00C03D, "Wiesemann & Theis Gmbh" },
  { 0x00C03E, "Fa. Gebr. Heller Gmbh" },
  { 0x00C03F, "Stores Automated Sys Inc" },
  { 0x00C040, "ECCI" },
  { 0x00C041, "Digital Transmission Sys" },
  { 0x00C042, "Datalux Corp" },
  { 0x00C043, "Stratacom" },
  { 0x00C044, "Emcom Corp" },
  { 0x00C045, "Isolation Sys Inc" },
  { 0x00C046, "Kemitron" },
  { 0x00C047, "Unimicro Sys Inc" },
  { 0x00C048, "Bay Technical Associates" },
  { 0x00C049, "US Robotics" },
  { 0x00C04D, "Mitec" },
  { 0x00C04E, "Comtrol Corp" },
  { 0x00C04F, "Dell" },
  { 0x00C050, "Toyo Denki Seizo K.K" },
  { 0x00C051, "Advanced Integration Research" },
  { 0x00C055, "Modular Computing Technologies" },
  { 0x00C056, "Somelec" },
  { 0x00C057, "Myco Electronics" },
  { 0x00C058, "Dataexpert Corp" },
  { 0x00C059, "Nippondenso Corp" },
  { 0x00C05B, "Networks Northwest Inc" },
  { 0x00C05C, "Elonex PLC" },
  { 0x00C05D, "L&N Technologies" },
  { 0x00C05E, "Vari-Lite Inc" },
  { 0x00C060, "ID Scandinavia A/S" },
  { 0x00C061, "Solectek Corp" },
  { 0x00C063, "Morning Star Tech" },
  { 0x00C064, "General Datacomm Ind Inc" },
  { 0x00C065, "Scope Comm Inc" },
  { 0x00C066, "Docupoint" },
  { 0x00C067, "United Barcode Industries" },
  { 0x00C068, "Philp Drake Electronics" },
  { 0x00C069, "California Microwave Inc" },
  { 0x00C06A, "Zahner-Elektrik Gmbh & Co" },
  { 0x00C06B, "OSI Plus Corp" },
  { 0x00C06C, "SVEC Computer Corp" },
  { 0x00C06D, "Boca Research" },
  { 0x00C06F, "Komatsu" },
  { 0x00C070, "Sectra" },
  { 0x00C071, "Areanex Comm" },
  { 0x00C072, "KNX" },
  { 0x00C073, "Xedia Corp" },
  { 0x00C074, "Toyoda Automatic Loom Works" },
  { 0x00C075, "Xante Corp" },
  { 0x00C076, "I-Data Int A-S" },
  { 0x00C077, "Daewoo Telecom" },
  { 0x00C078, "Computer Sys Engineering" },
  { 0x00C079, "Fonsys Co" },
  { 0x00C07A, "Priva BV" },
  { 0x00C07B, "Ascend" },
  { 0x00C07D, "RISC Developments" },
  { 0x00C07F, "Nupon Computing Corp" },
  { 0x00C080, "Netstar Inc" },
  { 0x00C081, "Metrodata" },
  { 0x00C082, "Moore Products Co" },
  { 0x00C084, "Data Link Corp" },
  { 0x00C085, "Canon" },
  { 0x00C086, "The Lynk Corp" },
  { 0x00C087, "UUNET Technologies Inc" },
  { 0x00C089, "Telindus Distribution" },
  { 0x00C08A, "Lauterbach Datentechnik Gmbh" },
  { 0x00C08B, "RISQ Modular Sys Inc" },
  { 0x00C08C, "Performance Technologies Inc" },
  { 0x00C08D, "Tronix Product Development" },
  { 0x00C08E, "Network Information Tech" },
  { 0x00C08F, "Matsushita Electric Works, " },
  { 0x00C090, "Praim S.R.L" },
  { 0x00C091, "Jabil Circuit" },
  { 0x00C092, "Mennen Medical Inc" },
  { 0x00C093, "Alta Research Corp" },
  { 0x00C095, "Znyx" },
  { 0x00C096, "Tamura Corp" },
  { 0x00C097, "Archipel SA" },
  { 0x00C098, "Chuntex Electronic Co" },
  { 0x00C09B, "Reliance" },
{ 0x00C09C, "TOA Electronic" },
{ 0x00C09D, "Distributed Sys Intl" },
  { 0x00C09F, "Quanta Computer Inc" },
  { 0x00C0A0, "Advance Micro Research" },
  { 0x00C0A1, "Tokyo Denshi Sekei Co" },
  { 0x00C0A2, "Intermedium A/S" },
  { 0x00C0A3, "Dual Enterprises Corp" },
  { 0x00C0A4, "Unigraf OY" },
  { 0x00C0A7, "SEEL" },
  { 0x00C0A8, "GVC Corp" },
  { 0x00C0A9, "Barron McCann" },
  { 0x00C0AA, "Silicon Valley Computer" },
  { 0x00C0AB, "Jupiter Tech Inc" },
  { 0x00C0AC, "Gambit Computer Comm" },
  { 0x00C0AD, "Computer Communication Sys" },
  { 0x00C0AE, "Towercom Co Inc" },
  { 0x00C0B0, "GCC Technologies,Inc" },
  { 0x00C0B2, "Norand Corp" },
  { 0x00C0B3, "Comstat Datacomm Corp" },
  { 0x00C0B4, "Myson Tech Inc" },
  { 0x00C0B5, "Corporate Network Sys Inc" },
  { 0x00C0B6, "Meridian Data Inc" },
  { 0x00C0B7, "American Power Conversion Corp" },
  { 0x00C0B8, "Fraser's Hill" }, 
  { 0x00C0B9, "Funk Software Inc" },
  { 0x00C0BA, "Netvantage" },
  { 0x00C0BB, "Forval Creative Inc" },
  { 0x00C0BD, "Inex Technologies" },
  { 0x00C0BE, "Alcatel - Sel" },
  { 0x00C0BF, "Tech Concepts" },
  { 0x00C0C0, "Shore MicroSys Inc" },
  { 0x00C0C1, "Quad/Graphics Inc" },
  { 0x00C0C2, "Infinite Networks" },
  { 0x00C0C3, "Acuson Computed Sonography" },
  { 0x00C0C4, "Computer Operational" },
  { 0x00C0C5, "SID Informatica" },
  { 0x00C0C6, "Personal Media Corp" },
  { 0x00C0C8, "Micro Byte Pty" },
  { 0x00C0C9, "Bailey Controls Co" },
  { 0x00C0CA, "Alfa" },
  { 0x00C0CB, "Control Tech Corp" },
  { 0x00C0CD, "Comelta S.A" },
  { 0x00C0D0, "Ratoc System Inc" },
  { 0x00C0D1, "Comtree Tech Corp" },
  { 0x00C0D2, "Syntellect Inc" },
  { 0x00C0D4, "Axon Networks Inc" },
  { 0x00C0D5, "Quancom Electronic Gmbh" },
  { 0x00C0D6, "J1 Sys" },
  { 0x00C0D9, "Quinte" },
  { 0x00C0DB, "IPC Corp" },
  { 0x00C0DC, "EOS Technologies" },
  { 0x00C0DE, "ZComm Inc" },
  { 0x00C0DF, "Kye Sys Corp" },
  { 0x00C0E1, "Sonic Solutions" },
  { 0x00C0E2, "Calcomp" },
  { 0x00C0E3, "Ositech Comm Inc" },
  { 0x00C0E4, "Landis & Gyr Powers Inc" },
  { 0x00C0E5, "GESPAC S.A" },
  { 0x00C0E6, "TXPORT" },
  { 0x00C0E7, "Fiberdata AB" },
  { 0x00C0E8, "Plexcom Inc" },
  { 0x00C0E9, "Oak Solutions" },
  { 0x00C0EA, "Array Tech" },
  { 0x00C0EC, "Dauphin Tech" },
  { 0x00C0ED, "US Army" },
  { 0x00C0EE, "Kyocera Corp" },
  { 0x00C0EF, "Abit Corp" },
  { 0x00C0F0, "Kingston Tech Corp" },
  { 0x00C0F1, "Shinko Electric Co" },
  { 0x00C0F2, "Transition Engineering Inc" },
  { 0x00C0F3, "Network Comm Corp" },
  { 0x00C0F4, "Interlink System Co" },
  { 0x00C0F5, "Metacomp Inc" },
  { 0x00C0F6, "Celan Tech Inc" },
  { 0x00C0F7, "Engage Communication" },
  { 0x00C0F8, "About Computing Inc" },
  { 0x00C0FA, "Canary Comm Inc" },
  { 0x00C0FB, "Advanced Tech Labs" },
  { 0x00C0FC, "ASDG Incorporated" },
  { 0x00C0FD, "Prosum" },
  { 0x00C0FF, "Box Hill Sys Corp" },
  { 0x00DD00, "Ungermann-Bass" },
  { 0x00DD01, "Ungermann-Bass" },
  { 0x00DD08, "Ungermann-Bass" },
  { 0x00E011, "Uniden Corp" },
  { 0x00E014, "Cisco" },
  { 0x00E01E, "Cisco" },
  { 0x00E029, "SMC" },
  { 0x00E02C, "AST" },
  { 0x00E034, "Cisco" },
  { 0x00E039, "Paradyne" },
  { 0x00E04F, "Cisco" },
  { 0x00E083, "Jato Technologies" },
  { 0x00E08F, "Cisco" },
  { 0x00E098, "Linksys" },
  { 0x00E0A3, "Cisco" },
  { 0x00E0B0, "Cisco Sys" },
  { 0x00E0B8, "AMD PCNet" },
  { 0x00E0C5, "BCOM Electronics Inc" },
  { 0x00E0F7, "Cisco" },
  { 0x00E0F9, "Cisco" },
  { 0x00E0FE, "Cisco" },
  { 0x01005E, "DoD Internet Multicast" },
  { 0x01000C, "Cisco" },
  { 0x020406, "BBN" },
  { 0x020701, "Racal-InterLAN" },
  { 0x020701, "Racal-Datacom" },
  { 0x026060, "3Com" },
  { 0x026086, "Satelcom MegaPac" },
  { 0x02608C, "3Com" },
  { 0x02AA3C, "Olivetti" },
  { 0x02CF1F, "CMC" },
  { 0x02E03B, "Prominet Corp" },
  { 0x02E6D3, "Bus-Tech" },
  { 0x080001, "Computer Vision" },
  { 0x080002, "3Com" },
  { 0x080003, "Advanced Computer Comm" },
  { 0x080005, "Symbolics" },
  { 0x080006, "Siemens Nixdorf" },
  { 0x080007, "Apple" },
  { 0x080008, "BBN" },
  { 0x080009, "Hewlett-Packard" },
  { 0x08000A, "Nestar Sys" },
  { 0x08000B, "Unisys" },
  { 0x08000D, "ICL" },
  { 0x08000E, "NCR/AT&T" },
  { 0x08000F, "SMC" },
  { 0x080010, "AT&T" },
  { 0x080011, "Tektronix" },
  { 0x080014, "Excelan" },
  { 0x080017, "National Semicond" },
  { 0x08001A, "Tiara" },
  { 0x08001B, "Data General" },
  { 0x08001E, "Apollo" },
  { 0x08001F, "Sharp" },
  { 0x080020, "Sun" },
  { 0x080022, "NBI" },
  { 0x080023, "Matsushita Denso" },
  { 0x080025, "CDC" },
  { 0x080026, "Norsk Data" },
  { 0x080027, "PCS Computer Sys GmbH" },
  { 0x080028, "TI" },
  { 0x08002B, "DEC" },
  { 0x08002E, "Metaphor" },
  { 0x08002F, "Prime Computer" },
  { 0x080030, "CERN" },
  { 0x080032, "Tigan" },
  { 0x080036, "Intergraph" },
  { 0x080037, "Fuji Xerox" },
  { 0x080038, "Bull" },
  { 0x080039, "Spider Sys" },
  { 0x08003B, "Torus Sys" },
  { 0x08003D, "cadnetix" },
  { 0x08003E, "Motorola" },
  { 0x080041, "Digital Comm. Assoc" },
  { 0x080044, "DAVID Sys" },
  { 0x080045, "Xylogics" },
  { 0x080046, "Sony" },
  { 0x080047, "Sequent" },
  { 0x080048, "Eurotherm Gauging Sys" },
  { 0x080049, "Univation" },
  { 0x08004C, "Encore" },
  { 0x08004E, "3Com" },
  { 0x080051, "Experdata" },
  { 0x080056, "Stanford University" },
  { 0x080057, "Evans & Sutherland" },
  { 0x080058, "DECsystem-20" },
  { 0x08005A, "IBM" },
  { 0x080066, "AGFA" },
  { 0x080067, "Comdesign" },
  { 0x080068, "Ridge" },
  { 0x080069, "Silicon Graphics" },
  { 0x08006A, "ATTst" },
  { 0x08006E, "Excelan" },
  { 0x080070, "Mitsubishi" },
  { 0x080074, "Casio" },
  { 0x080075, "DDE" },
  { 0x080077, "Retix" },
  { 0x080079, "Silicon Graphics" },
  { 0x08007C, "Vitalink" },
  { 0x080080, "XIOS" },
  { 0x080081, "Crosfield Electronics" },
  { 0x080083, "Seiko Denshi" },
  { 0x080086, "Imagen/QMS" },
  { 0x080087, "XypleX" },
  { 0x080088, "McDATA Corp" },
  { 0x080089, "Kinetics" },
  { 0x08008B, "Pyramid" },
  { 0x08008D, "XyVision" },
  { 0x08008E, "Tandem/Solbourne" },
  { 0x08008F, "Chipcom Corp" },
  { 0x080090, "Retix" },
  { 0x09006A, "AT&T" },
  { 0x10005A, "IBM" },
  { 0x100090, "Hewlett-Packard" },
  { 0x1000D4, "DEC" },
  { 0x1000E0, "Apple" },
  { 0x2E2E2E, "Meditech Sys" },
  { 0x3C0000, "3Com" },
  { 0x400003, "NetWare" },
  { 0x444553, "Microsoft" },
  { 0x444649, "DFI" },
  { 0x475443, "GTC" },
  { 0x484453, "HDS" },
  { 0x484C00, "Network Solutions" },
  { 0x4854E8, "Winbond" },
  { 0x4C424C, "Information Modes" },
  { 0x52544C, "Novell 2000" },
  { 0x5254AB, "REALTEK" },
  { 0x565857, "Aculab" },
  { 0x800010, "AT&T" },
  { 0x80AD00, "CNET Tech" },
  { 0xAA0000, "DEC" },
  { 0xAA0001, "DEC" },
  { 0xAA0002, "DEC" },
  { 0xAA0003, "DEC" },
  { 0xAA0004, "DEC" },
  { 0xC00000, "Western Digital" },
  { 0xEC1000, "Enance Source Co" },
  { 0xFFFFFF, "IP Broadcast" },
  { 0x0, NULL }
};  

VendorInfo* vendorHash[HASHNAMESIZE];

/* *********************************** */

static void addVendorTableEntry(VendorInfo* entry) {
  u_int idx;

  idx = (u_int)(entry->vendorId % HASHNAMESIZE);

#ifdef DEBUG
  printf("%d %x '%s'\n", idx,
	 entry->vendorId,
	 entry->vendorName);
#endif

  for(;;) {
    if(vendorHash[idx] == NULL) {      
      vendorHash[idx] = entry;
      break;
    }    
    idx = (idx+1)%HASHNAMESIZE;
  }
}

/* *********************************** */

char* getVendorInfo(u_char* ethAddress) {
  u_int idx;
  unsigned long vendorValue;
  VendorInfo* cursor;
  u_char *vendorValueChar;

  vendorValue = 256*256*(unsigned long)ethAddress[0] 
    + 256*(unsigned long)ethAddress[1] 
    + (unsigned long)ethAddress[2];
  idx = (u_int)((u_int)vendorValue % HASHNAMESIZE);

#ifdef DEBUG
  printf("%d %ld\n", idx, vendorValue);
#endif

  for(;;) {
    cursor = vendorHash[idx];
    
    if(vendorHash[idx] == NULL) {
      /* Unknown vendor */
      return("");
    } else if(vendorHash[idx] != NULL) {
      if(vendorHash[idx]->vendorId == vendorValue)
	return(vendorHash[idx]->vendorName);
    }

    idx = (idx+1)%HASHNAMESIZE;
  }
}

/* *********************************** */

void createVendorTable() 
{
  int idx;

  for(idx=0; vendorInfo[idx].vendorId != 0x0; idx++)
    addVendorTableEntry(&vendorInfo[idx]);
}

